@@ -43,7 +43,8 @@ def func():
                 log("panelPlugin.py 破解成功")
                 # 重启面板
                 try:
-                    subprocess.Popen(["/etc/init.d/bt", "restart"],stdout=subprocess.PIPE)
+                    info = subprocess.Popen(["/etc/init.d/bt", "restart"],stdout=subprocess.PIPE)
+                    log(info.stdout.read().decode('utf-8'))
                 except:
                     pass
 
@@ -75,7 +76,8 @@ def func():
                 log("total_main.py 破解成功")
                 # 重启面板
                 try:
-                    subprocess.Popen(["/etc/init.d/bt", "restart"],stdout=subprocess.PIPE)
+                    info = subprocess.Popen(["/etc/init.d/bt", "restart"], stdout=subprocess.PIPE)
+                    log(info.stdout.read().decode('utf-8'))
                 except:
                     pass
     except Exception as e :
@@ -105,7 +107,8 @@ def func():
             log("config.py 破解成功")
             # 重启面板
             try:
-                subprocess.Popen(["/etc/init.d/bt", "restart"], stdout=subprocess.PIPE)
+                info = subprocess.Popen(["/etc/init.d/bt", "restart"], stdout=subprocess.PIPE)
+                log(info.stdout.read().decode('utf-8'))
             except:
                 pass
     except Exception as e:
@@ -113,7 +116,6 @@ def func():
 
 
 
-
 def  main():
     log('start success...')
     print('start success...')
